@@ -1,3 +1,7 @@
+r"""Contain the main features of the ``objectory`` package."""
+
+from __future__ import annotations
+
 __all__ = ["AbstractFactory", "OBJECT_INIT", "OBJECT_TARGET", "Registry", "factory"]
 
 from objectory.abstract_factory import AbstractFactory
