@@ -1,12 +1,18 @@
+r"""Contain some utility functions or helpers."""
+
+from __future__ import annotations
+
 __all__ = [
     "all_child_classes",
     "full_object_name",
     "import_object",
     "instantiate_object",
     "is_lambda_function",
+    "is_object_config",
     "resolve_name",
 ]
 
+from objectory.utils.config import is_object_config
 from objectory.utils.name_resolution import resolve_name
 from objectory.utils.object_helpers import (
     all_child_classes,
